/***************************************************************************
 * MoioChart Library - graphs and charts made easy                         *
 * Copyright (C) 2005 by Silvio Moioli                                     *
 * silvio@moioli.net, http://www.moioli.net                                *  
 *                                                                         *
 * This program is free software; you can redistribute it and/or           *
 * modify it under the terms of the GNU General Public License             *
 * as published by the Free Software Foundation; either version 2          *
 * of the License, or (at your option) any later version.                  *
 *                                                                         *
 * This program is distributed in the hope that it will be useful,         *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU General Public License       *
 * along with this program; if not, write to the Free Software             *
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,              *
 * MA  02110-1301, USA.                                                    *
 ***************************************************************************/

package net.moioli.drawables;

import net.moioli.chart.DrawableI;
import net.moioli.chart.GraphicsI;
import net.moioli.chart.Scale;

/**
 * Represents a single point on the cartesian plane, and implementing DrawableI
 * is drawable.
 * 
 * @author Silvio Moioli
 * @version 2005/10/5
 */
class DrawablePoint extends DoublePoint implements DrawableI {
    /**
     * Default constructor.
     */
    public DrawablePoint() {
        super();
    }

    /**
     * This method is automatically called by DefaultChart to draw the objects
     * it contains, so end users should never call drawMe directly. Inside this
     * method there must be all the code to draw the object on a DefaultChart,
     * and all the operations which involve scaling should be done via the
     * passed Scale object.
     * 
     * @param g
     *            the surface where this object will be drawn
     * @param s
     *            the DefaultChart's Scale object
     * @param c
     *            the color to be used for drawing
     */
    public void drawMe(GraphicsI g, Scale s, Object c) {
        g.setColor(c);
        int x1 = s.getX(this.x);
        int y1 = s.getY(this.y);
        g.drawLine(x1, y1, x1, y1);
    }

    /**
     * Returns the minimum y value that should be represented in the
     * DefaultChart for this object to be drawn properly. <br />
     * 
     * @param minX
     *            the minimum x value represented in this DefaultChart
     * @param maxX
     *            the maximum x value represented in this DefaultChart
     * @return the minimum y value
     */
    public double minY(double minX, double maxX) {
        double result;
        if ((this.x >= minX) && (this.x <= maxX)) {
            result = this.y;
        } else {
            result = java.lang.Double.NaN;
        }
        return result;
    }

    /**
     * Returns the maximum y value that should be represented in the
     * DefaultChart for this object to be drawn properly. <br />
     * 
     * @param minX
     *            the minimum x value represented in this DefaultChart
     * @param maxX
     *            the maximum x value represented in this DefaultChart
     * @return the maximum y value
     */
    public double maxY(double minX, double maxX) {
        double result;
        if ((this.x >= minX) && (this.x <= maxX)) {
            result = this.y;
        } else {
            result = java.lang.Double.NaN;
        }
        return result;
    }
}