/***************************************************************************
 * MoioChart Library - graphs and charts made easy                         *
 * Copyright (C) 2005 by Silvio Moioli                                     *
 * silvio@moioli.net, http://www.moioli.net                                *  
 *                                                                         *
 * This program is free software; you can redistribute it and/or           *
 * modify it under the terms of the GNU General Public License             *
 * as published by the Free Software Foundation; either version 2          *
 * of the License, or (at your option) any later version.                  *
 *                                                                         *
 * This program is distributed in the hope that it will be useful,         *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU General Public License       *
 * along with this program; if not, write to the Free Software             *
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,              *
 * MA  02110-1301, USA.                                                    *
 ***************************************************************************/

package net.moioli.drawables;

import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.lang.Number;

import net.moioli.chart.DrawableI;
import net.moioli.chart.GraphicsI;
import net.moioli.chart.Scale;

/**
 * A nice class to draw a histogram out of a Map table of data. <br />
 * It will draw a histogram with the values and will use the Map keys as lables.
 * <br />
 * Attention: this class expects you use Number derived objects as the map
 * values (like Double or Integer). Not doing so might raise
 * ClassCastExceptions.
 * 
 * @see java.lang.Number
 * @see java.util.Map
 * 
 * @author Silvio Moioli
 * @version 2005/10/5
 */
public class Histogram extends HashMap implements DrawableI {
    /**
     * Constructs a new, empty Histogram.
     */
    public Histogram() {
        super();
    }

    /**
     * @see net.moioli.chart.DrawableI#minY(double, double) TODO: find a better
     *      strategy to do this (use keys as values in a TreeMap?)
     */
    public double minY(double minX, double maxX) {
        double min = 0;
        if (this.isEmpty() == false) {
            min = ((Number) Collections.min(this.values())).doubleValue();
            if (min > 0) {
                min = 0;
            }
        }
        return min;
    }

    /**
     * @see net.moioli.chart.DrawableI#maxY(double, double)
     */
    public double maxY(double minX, double maxX) {
        double max = 0;
        if (this.isEmpty() == false) {
            max = ((Number) Collections.max(this.values())).doubleValue();
            if (max < 0) {
                max = 0;
            }
        }
        return max;
    }

    /**
     * @see net.moioli.chart.DrawableI#drawMe(GraphicsI, Scale, Object)
     */
    public void drawMe(GraphicsI g, Scale s, Object c) {
        if (this.size() > 0) {
            // Range of all the values
            double range = s.getMaxX() - s.getMinX();
            // A column's width
            double width = range / this.size();

            Collection es = this.entrySet();
            Iterator i = es.iterator();
            int n = 0;// current bar number
            while (i.hasNext()) {
                Map.Entry me = (Map.Entry) i.next();
                double v = ((Number) me.getValue()).doubleValue();
                int[] xPoints = new int[4];
                int[] yPoints = new int[4];
                int lx = s.getXMeasure(width);
                int labelY;
                if (v > 0) {
                    int ly = s.getYMeasure(v);
                    xPoints[0] = s.getX(s.getMinX() + width * n);
                    yPoints[0] = s.getY(v);
                    xPoints[1] = xPoints[0] + lx;
                    yPoints[1] = yPoints[0];
                    xPoints[2] = xPoints[1];
                    yPoints[2] = yPoints[0] + ly;
                    xPoints[3] = xPoints[0];
                    yPoints[3] = yPoints[2];
                    labelY = s.getY(v) - g.getStringHeight();
                } else {
                    int ly = s.getYMeasure(-v);
                    xPoints[0] = s.getX(s.getMinX() + width * n);
                    yPoints[0] = s.getY(0);
                    xPoints[1] = xPoints[0] + lx;
                    yPoints[1] = yPoints[0];
                    xPoints[2] = xPoints[1];
                    yPoints[2] = yPoints[0] + ly;
                    xPoints[3] = xPoints[0];
                    yPoints[3] = yPoints[2];
                    labelY = s.getY(0) + ly - g.getStringHeight();
                }
                g.setColor(g.getRandomColor());
                g.fillPolygon(xPoints, yPoints, 4);
                g.setColor(g.getBlackColor());
                g.drawString(me.getKey() + ", " + me.getValue(), xPoints[0],
                        labelY);
                n++;
            }
        }
    }
}