/***************************************************************************
 * MoioChart Library - graphs and charts made easy                         *
 * Copyright (C) 2005 by Silvio Moioli                                     *
 * silvio@moioli.net, http://www.moioli.net                                *  
 *                                                                         *
 * This program is free software; you can redistribute it and/or           *
 * modify it under the terms of the GNU General Public License             *
 * as published by the Free Software Foundation; either version 2          *
 * of the License, or (at your option) any later version.                  *
 *                                                                         *
 * This program is distributed in the hope that it will be useful,         *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU General Public License       *
 * along with this program; if not, write to the Free Software             *
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,              *
 * MA  02110-1301, USA.                                                    *
 ***************************************************************************/

package net.moioli.drawables;

import net.moioli.chart.DrawableI;
import net.moioli.chart.GraphicsI;
import net.moioli.chart.Scale;

/**
 * Draws MoioChart's logo.
 * 
 * @author Silvio Moioli
 * @version 2005/10/5
 */
public class Logo implements DrawableI {
    
    /**
     * Default constructor. 
     */
    public Logo() {
        super();
    }

    /**
     * Implements DrawableI drawing this object.
     * 
     * @param g
     *            the surface where this object will be drawn
     * @param s
     *            the DefaultChart's Scale object
     * @param c
     *            the color to be used for drawing
     */
    public void drawMe(GraphicsI g, Scale s, Object c) {
        g.setColor(c);
        g.drawString("Powered by MoioChart", 0, 0);
    }

    /**
     * Since the Logo will be drawn regardless of the scale, always return NaN.
     * 
     * @param minX
     *            the minimum x value represented in this DefaultChart
     * @param maxX
     *            the maximum x value represented in this DefaultChart
     * @return NaN
     */
    public double maxY(double minX, double maxX) {
        return Double.NaN;
    }

    /**
     * Since the Logo will be drawn regardless of the scale, always return NaN.
     * 
     * @param minX
     *            the minimum x value represented in this DefaultChart
     * @param maxX
     *            the maximum x value represented in this DefaultChart
     * @return NaN
     */
    public double minY(double minX, double maxX) {
        return Double.NaN;
    }
}