/***************************************************************************
 * MoioChart Library - graphs and charts made easy                         *
 * Copyright (C) 2005 by Silvio Moioli                                     *
 * silvio@moioli.net, http://www.moioli.net                                *  
 *                                                                         *
 * This program is free software; you can redistribute it and/or           *
 * modify it under the terms of the GNU General Public License             *
 * as published by the Free Software Foundation; either version 2          *
 * of the License, or (at your option) any later version.                  *
 *                                                                         *
 * This program is distributed in the hope that it will be useful,         *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU General Public License       *
 * along with this program; if not, write to the Free Software             *
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,              *
 * MA  02110-1301, USA.                                                    *
 ***************************************************************************/

package net.moioli.drawables;

/**
 * A simple interface that defines a parametric mathematical function (x(t),
 * y(t)).
 * 
 * @author Silvio Moioli
 * @version 2005/10/5
 */
public interface PlaneCurveI {
    /**
     * Returns the x value corresponding to the specified t (any point in this
     * function has coordinates (x(t),y(t)).
     * 
     * @param t
     *            the parameter's value
     * @return the point's abscissa
     */
    double x(double t);

    /**
     * Returns the y value corresponding to the specified t (any point in this
     * function has coordinates (x(t),y(t)).
     * 
     * @param t
     *            the parameter's value
     * @return the point's ordinate
     */
    double y(double t);

    /**
     * Returns the maximum value the t parameter can assume.
     * 
     * @return the maximum t value
     */
    double getMaxT();

    /**
     * Sets the maximum value the t parameter can assume.
     * 
     * @param t
     *            the maximum t value
     */
    void setMaxT(double t);
}
